/* Get the different modules */
var gulp        = require('gulp');
var gutil       = require('gulp-util');
var bower       = require('bower');
var concat      = require('gulp-concat');
var sass        = require('gulp-sass');
var minifyCss   = require('gulp-minify-css');
var rename      = require('gulp-rename');
var sh          = require('shelljs');
var browserSync = require('browser-sync');
var gettext     = require('gulp-angular-gettext');
var inject      = require('gulp-inject');
var reload      = browserSync.reload;
var paths       = { 
  sass: [ './scss/**/*.scss' ],
  css:  [ './www/css/*.css'  ]
};

/*
** Default 'gulp'
*/
gulp.task('default', ['sass', 'serve', 'sass-watch', 'css-watch', 'inject']);

/*
** 'gulp serve' launches server and relaunches on html change
*/
gulp.task('serve', function() {
  browserSync({
    server: {
      baseDir: 'www'
    }
  });

  gulp.watch(['**/*.html', '**/*.js'], {cwd: 'www'}, reload);
});

gulp.task('sass', function(done) {
  gulp.src('./scss/cj.app.scss')
    .pipe(sass())
    .pipe(gulp.dest('./www/css/'))
    .pipe(minifyCss({
      keepSpecialComments: 0
    }))
    .pipe(rename({ extname: '.min.css' }))
    .pipe(gulp.dest('./www/css/'))
    .on('end', done);
});

gulp.task('sass-watch', function() {
  gulp.watch(paths.sass, ['sass', reload]);
});

gulp.task('css-watch', function() {
  gulp.watch(paths.css, reload);
});

gulp.task('inject', function() {
  var sources = gulp.src(['!./www/lib/**/*.js', './www/**/*.js', './www/css/*.min.css'], {read: false});

  gulp.src('./www/index.html')
    .pipe(inject(sources, {ignorePath: 'www', addRootSlash: false, exclude: ['./www/lib/'] }))
    .pipe(gulp.dest('./www'));
});
